# Scoutr

A simple way to put an API in front of a DynamoDB backend.

A Golang implementation is available at https://github.com/MichaelPalmer1/scoutr-go.

## Documentation

Documentation is available at [https://geskunkworks.github.io/scoutr/](https://geskunkworks.github.io/scoutr/).
